@@ -9,8 +9,8 @@ _wallet_connect = components.declare_component("wallet_connect", path=build_dir)
 # _wallet_connect = components.declare_component("wallet_connect", url="http://localhost:3001")
 
 # default contract address is for ocean token
-def wallet_connect(label, key=None, message="Connect Wallet", contract_address="0xCfDdA22C9837aE76E0faA845354f33C62E03653a",amount="0.01", to_address="", message_to_encrypt="", encrypted_string="", encrypted_symmetric_key="", auth_nft_contract_address=""):
-    return _wallet_connect(label=label, default="not", key=key, message=message, contract_address=contract_address, amount=amount, to_address=to_address, message_to_encrypt=message_to_encrypt, encrypted_string=encrypted_string, encrypted_symmetric_key=encrypted_symmetric_key, auth_nft_contract_address=auth_nft_contract_address)
+def wallet_connect(label, key=None, message="Connect Wallet", contract_address="0xCfDdA22C9837aE76E0faA845354f33C62E03653a",amount="0.01", to_address="", message_to_encrypt="", encrypted_string="", encrypted_symmetric_key="", auth_nft_contract_address="", chain_name="polygon"):
+    return _wallet_connect(label=label, default="not", key=key, message=message, contract_address=contract_address, amount=amount, to_address=to_address, message_to_encrypt=message_to_encrypt, encrypted_string=encrypted_string, encrypted_symmetric_key=encrypted_symmetric_key, auth_nft_contract_address=auth_nft_contract_address, chain_name=chain_name)
 
 
 # wallet_button = wallet_connect(label="wallet", key="wallet")
